package iotcloud;
import java.nio.ByteBuffer;

/**
 * TableStatus entries record the current size of the data structure
 * in slots.  Used to remember the size and to perform resizes.
 * @author Brian Demsky
 * @version 1.0
 */


class TableStatus extends Entry {
	private int maxslots;

	TableStatus(Slot slot, int _maxslots) {
		super(slot);
		maxslots=_maxslots;
	}

	int getMaxSlots() {
		return maxslots;
	}

	static Entry decode(Slot slot, ByteBuffer bb) {
		int maxslots=bb.getInt();
		return new TableStatus(slot, maxslots);
	}

	void encode(ByteBuffer bb) {
		bb.put(Entry.TypeTableStatus);
		bb.putInt(maxslots);
	}

	int getSize() {
		return Integer.BYTES+Byte.BYTES;
	}

	byte getType() {
		return Entry.TypeTableStatus;
	}

	Entry getCopy(Slot s) {
		return new TableStatus(s, maxslots);
	}
}
